# coding: utf-8

# flake8: noqa

"""
    42di API Reference

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: support@42docs.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import apis into sdk package
from swagger_client.api.boards_api import BoardsApi
from swagger_client.api.datasets_api import DatasetsApi
from swagger_client.api.projects_api import ProjectsApi
from swagger_client.api.teams_api import TeamsApi
from swagger_client.api.users_api import UsersApi
# import ApiClient
from swagger_client.api_client import ApiClient
from swagger_client.configuration import Configuration
# import models into sdk package
from swagger_client.models.board import Board
from swagger_client.models.data_file import DataFile
from swagger_client.models.dataset import Dataset
from swagger_client.models.error_message import ErrorMessage
from swagger_client.models.patch_action import PatchAction
from swagger_client.models.project import Project
from swagger_client.models.project_sub import ProjectSub
from swagger_client.models.team import Team
from swagger_client.models.token import Token
from swagger_client.models.topic import Topic
from swagger_client.models.user import User
